import { EventEmitter } from 'events';
import { WebSocketServer, WebSocket } from 'ws';
import { Message } from './message';
import { ComServerMethods, UploadFileParams } from './types';
import { Router } from '@zhinjs/plugin-http-server';
import { ComWechatAdapter } from './index';
import { Dict } from 'zhin';
export declare class Client extends EventEmitter {
    #private;
    private adapter;
    config: Client.Config & Dict;
    private router;
    self_id: string;
    constructor(adapter: ComWechatAdapter, config: Client.Config & Dict, router: Router);
    get app(): import("zhin").App | null;
    get logger(): Logger;
    reTryCount: number;
    ws?: WebSocket;
    wss: Map<string, WebSocketServer>;
    start(): Promise<void>;
    private dispatch;
    stop(): Promise<void>;
    sendPayload<T extends keyof ComServerMethods>(payload: {
        action: T;
        params: Parameters<ComServerMethods[T]>[0];
        echo?: number | string;
    }): Promise<ReturnType<ComServerMethods[T]>>;
    sendPrivateMsg(user_id: string, message: Message.Sendable): Promise<void>;
    sendGroupMsg(group_id: string, message: Message.Sendable): Promise<void>;
    getGroupList(): Promise<import("./types").GroupInfo[]>;
    getGroupInfo(group_id: string): Promise<import("./types").GroupInfo>;
    getFriendList(): Promise<import("./types").FriendInfo[]>;
    getGroupMemberList(group_id: string): Promise<import("./types").UserInfo[]>;
    getGroupMemberInfo(group_id: string, user_id: string): Promise<import("./types").UserInfo>;
    searchContact(condition: string): Promise<import("./types").FriendInfo>;
    setGroupName(group_id: string, group_name: string): Promise<null>;
    uploadFile(params: UploadFileParams): Promise<{
        file_id: string;
    }>;
    getWechatVersion(): Promise<string>;
    setWechatVersion(version: string): Promise<null>;
    getPublicAccountList(): Promise<import("./types").PublicAccountInfo[]>;
    followPublicAccount(user_id: string): Promise<null>;
    approveFriendRequest(v3: string, v4: string): Promise<null>;
    checkFriendStatus(user_id: string): Promise<import("./types").FriendStatus>;
    deleteFriend(user_id: string): Promise<null>;
    setGroupAnnouncement(group_id: string, content: string): Promise<null>;
    addGroupMember(group_id: string, user_id: string): Promise<null>;
    deleteGroupMember(group_id: string, user_id: string): Promise<null>;
    getPublicHistory(public_id: string, offset: number): Promise<import("./types").PublicMessage[]>;
    setFriendRemark(friend_id: string, remark: string): Promise<null>;
    setGroupRemark(group_id: string, remark: string): Promise<null>;
    setGroupNickname(group_id: string, nickname: string): Promise<null>;
    sendForwardMsg(user_id: string, message_id: string): Promise<null>;
    processMessage(message: Message.Sendable): Promise<Message.Segment[]>;
    getBrief(message: Message.Sendable): string;
}
export declare namespace Client {
    type WsConfig = {
        url?: string;
        max_reconnect_count?: number;
        reconnect_interval?: number;
    };
    export type ApiResult = {
        status: 'ok' | 'failed';
        retcode: 1400 | 1401 | 1403 | 1404;
        data: any;
        echo?: string | number;
    };
    export type EventPayload = {
        time: number;
        self_id: number;
        type: 'message' | 'notice' | 'request' | 'meta';
        detail_type: string;
    } & Dict;
    type WsReverseConfig = {
        prefix?: string;
    };
    export interface ConfigMap {
        ws?: WsConfig;
        ws_reverse?: WsReverseConfig;
    }
    export type Config<T extends keyof ConfigMap = keyof ConfigMap> = {
        type: T;
        access_token?: string;
        timeout?: number;
    } & ConfigMap[T];
    export const defaultConfig: {
        ws: {
            host: string;
            port: number;
            max_reconnect_count: number;
            reconnect_interval: number;
        };
        ws_reverse: {
            prefix: string;
        };
    };
    export {};
}
